@@ -1121,7 +1121,15 @@ _ck_seat_set_kind (CkSeat    *seat,
                    CkSeatKind kind)
 {
         seat->priv->kind = kind;
-        console_kit_seat_set_name (CONSOLE_KIT_SEAT (seat), seat->priv->id);
+        if (kind == CK_SEAT_KIND_STATIC) {
+                console_kit_seat_set_name (CONSOLE_KIT_SEAT (seat), "seat0");
+        } else {
+                /* FIXME: At some point we should properly map this to the
+                 * udev/devattr seat name when we do multi-seat */
+                gchar *sid = g_path_get_basename(seat->priv->id);
+                console_kit_seat_set_name (CONSOLE_KIT_SEAT (seat), sid);
+                g_free(sid);
+        }
 }
 
 static void
@@ -1167,7 +1175,7 @@ ck_seat_get_property (GObject    *object,
                 g_value_set_string (value, self->priv->id);
                 break;
         case PROP_KIND:
-                g_value_set_string (value, self->priv->id);
+                g_value_set_enum (value, self->priv->kind);
                 break;
         case PROP_CONNECTION:
                 g_value_set_pointer (value, self->priv->connection);
